
# coding: utf-8

# In[47]:


import matplotlib.pyplot as plt
from numpy import loadtxt, linspace, polyfit
from math import log, pi, sqrt
get_ipython().run_line_magic('matplotlib', 'inline')


# In[81]:


def invert_input():
    file = loadtxt('data/invert_input.txt')
    U1 = file[:,0]
    UO = file[:,1] * (-1)
    R1 = 10
    R2 = 20
    x = linspace(min(U1), max(U1))
    
    plt.figure(figsize=(7,5))
    plt.plot(U1, UO, 'o', label='measurment')
    plt.plot(x, -2 * x, label='$- \, R_2 \, / \, R_1 \cdot U_1$')
    plt.xlabel('$U_1$ [V]', size=12)
    plt.ylabel('$U_O$ [V]', size=12)
    plt.legend(prop={'size': 12})
    plt.savefig('invert_input.png', dpi=120)
    
invert_input()


# In[114]:


def invert_input_bandwidth():
    file = loadtxt('data/noninvert_input.txt')
    f = file[:,0]
    Uin = file[:,1]
    Uout = file[:,2]
    Au = Uout / Uin
    
    log_f = []
    for i in range(len(f)):
        log_f.append(log(f[i], 10))
    line = max(Au) / sqrt(2)            
    x = linspace(min(log_f), max(log_f))
    
    A1, A0 = polyfit(log_f[6:8], Au[6:8], 1)
    x2 = linspace(4.03, 4.5, 100)
    
    line2 = 0
    for i in range(len(x2)):
        #print(round(line, 2), round(A0 + A1 * x2[i], 2))
        if round(A0 + A1 * x2[i], 2) == round(line, 2):
            line2 = x2[i]
    x3 = linspace(0, 2.1)
        
    plt.figure(figsize=(7,5))
    plt.plot(log_f, Au, 'o')
    plt.plot(x, [line for i in range(50)])#, label='$A_{{u, max}} / \sqrt{{2}} = {0:.2f}$'.format(line))
    plt.plot(x2, A0 + A1 * x2)
    #plt.plot([line2 for i in range(50)], x3, label='log($\omega$) = {0:.2f}'.format(line2))
    plt.xlabel('log($\omega$)', size=13)
    plt.ylabel('$A_u$', size=13)
    plt.text(4.5, 1.65, '$A_{{u, max}} \, / \, \sqrt{{2}} = {0:.2f}$ V\nlog($\omega$) = {1:.2f}\n$\omega = ${2:.0f} Hz'.format(line, line2, 10**line2), size=12)
    
invert_input_bandwidth()


# In[40]:


def low_pass():
    file = loadtxt('data/low_pass.txt')
    f = file[:,0]
    Uin = file[:,1]
    Uout = file[:,2]
    Au = Uout / Uin
    
    log_f = []
    for i in range(len(f)):
        log_f.append(log(f[i], 10))
        
    plt.figure(figsize=(7,5))
    plt.plot(log_f, Au, 'o')
    plt.xlabel('log($\omega$)', size=13)
    plt.ylabel('$A_u$', size=13)
    
low_pass()


# In[92]:


def differential_amp():
    file = loadtxt('data/differential_amplifier.txt')
    U1 = file[:,0]
    U2 = file[:,1]
    UO = file[:,2]
    delta_U = U2 - U1
    x = linspace(min(delta_U), max(delta_U))
    
    plt.figure(figsize=(7,5))
    plt.plot(delta_U, UO, 'o', label='measurment')
    plt.plot(x, 2 * x, label='$2 \cdot (U_2 - U_1)$')
    plt.xlabel('$U_2 - U_1$ [V]', size=13)
    plt.ylabel('$U_O$ [V]', size=13)
    plt.legend(prop={'size': 12})
    
differential_amp()

